@@ -4,10 +4,10 @@ import socket
 import json
 import sys
 import os
-import log_convert
+from pylgocq import log_convert
 from datetime import datetime
 
-version = "0.7.4"
+version = "0.7.5"
 
 
 class ViewForm(npyscreen.Form):
